==> igniteui-react-charts-18.7.0-beta.2.tgz: package/esm5/lib/TypicalPriceIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { TypicalPriceIndicatorStrategy } from "./TypicalPriceIndicatorStrategy";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var TypicalPriceIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TypicalPriceIndicator, _super);
    function TypicalPriceIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TypicalPriceIndicator.prototype.bi = function () {
        return new TypicalPriceIndicator();
    };
    TypicalPriceIndicator.prototype.get_abm = function () {
        return new TypicalPriceIndicatorStrategy();
    };
    Object.defineProperty(TypicalPriceIndicator.prototype, "abm", {
        get: function () {
            return this.get_abm();
        },
        enumerable: false,
        configurable: true
    });
    TypicalPriceIndicator.prototype.get_abz = function () {
        return TypicalPriceIndicator.$;
    };
    Object.defineProperty(TypicalPriceIndicator.prototype, "abz", {
        get: function () {
            return this.get_abz();
        },
        enumerable: false,
        configurable: true
    });
    TypicalPriceIndicator.$t = markType(TypicalPriceIndicator, 'TypicalPriceIndicator', StrategyBasedIndicator.$);
    return TypicalPriceIndicator;
}(StrategyBasedIndicator));
export { TypicalPriceIndicator };

==> igniteui-react-charts-18.7.5-beta.2.tgz: package/esm5/lib/TypicalPriceIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { TypicalPriceIndicatorStrategy } from "./TypicalPriceIndicatorStrategy";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var TypicalPriceIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TypicalPriceIndicator, _super);
    function TypicalPriceIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TypicalPriceIndicator.prototype.bj = function () {
        return new TypicalPriceIndicator();
    };
    TypicalPriceIndicator.prototype.get_abv = function () {
        return new TypicalPriceIndicatorStrategy();
    };
    Object.defineProperty(TypicalPriceIndicator.prototype, "abv", {
        get: function () {
            return this.get_abv();
        },
        enumerable: false,
        configurable: true
    });
    TypicalPriceIndicator.prototype.get_ab8 = function () {
        return TypicalPriceIndicator.$;
    };
    Object.defineProperty(TypicalPriceIndicator.prototype, "ab8", {
        get: function () {
            return this.get_ab8();
        },
        enumerable: false,
        configurable: true
    });
    TypicalPriceIndicator.$t = markType(TypicalPriceIndicator, 'TypicalPriceIndicator', StrategyBasedIndicator.$);
    return TypicalPriceIndicator;
}(StrategyBasedIndicator));
export { TypicalPriceIndicator };
